@@ -433,6 +433,8 @@ parole_gst_set_video_color_balance (ParoleGst *gst)
 		  "saturation", &saturation_value,
 		  NULL);
     
+    TRACE ("Setting video color balance");
+    
     g_object_set (G_OBJECT (video_sink),
 		  "brightness", brightness_value,
 		  "contrast", contrast_value,
@@ -448,6 +450,7 @@ parole_gst_set_video_color_balance (ParoleGst *gst)
 static void
 parole_gst_set_x_overlay (ParoleGst *gst)
 {
+    
     GstElement *video_sink;
     
     g_object_get (G_OBJECT (gst->priv->playbin),
@@ -460,6 +463,7 @@ parole_gst_set_x_overlay (ParoleGst *gst)
 				  GDK_WINDOW_XWINDOW (GTK_WIDGET (gst)->window));
     
     gst_object_unref (video_sink);
+    
 }
 
 static gboolean
@@ -1313,7 +1317,7 @@ parole_gst_construct (GObject *object)
     g_object_set (G_OBJECT (gst->priv->playbin),
 		  "video-sink", gst->priv->video_sink,
 		  NULL);
-
+    
     /*
      * Listen to the bus events.
      */
@@ -1515,19 +1519,17 @@ parole_gst_terminate_internal (ParoleGst *gst, gboolean fade_sound)
 {
     gboolean playing_video;
     
-    g_mutex_lock (gst->priv->lock);
-    
-    parole_stream_init_properties (gst->priv->stream);
-    gst->priv->target = GST_STATE_NULL;
-    
-    g_mutex_unlock (gst->priv->lock);
-
-    parole_window_busy_cursor (GTK_WIDGET (gst)->window);
-    
     g_object_get (G_OBJECT (gst->priv->stream), 
 		  "has-video", &playing_video,
 		  NULL);
     
+    g_mutex_lock (gst->priv->lock);
+    gst->priv->target = GST_STATE_NULL;
+    parole_stream_init_properties (gst->priv->stream);
+    g_mutex_unlock (gst->priv->lock);
+
+    parole_window_busy_cursor (GTK_WIDGET (gst)->window);
+    
     if ( fade_sound && gst->priv->state == GST_STATE_PLAYING && !playing_video )
     {
 	gdouble volume;
@@ -1819,9 +1821,6 @@ void parole_gst_shutdown (ParoleGst *gst)
 
     g_object_unref (gst->priv->bus);
     
-    if ( gst->priv->vis_sink )
-        g_object_unref (gst->priv->vis_sink);
-        
     gst_element_set_state (gst->priv->playbin, GST_STATE_VOID_PENDING);
 
     g_object_unref (gst->priv->playbin);
